==> exit-options_23.8.tar.xz: BUILD/translations/exit-options_is.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="is">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="30"/>
        <source>Restart Fluxbox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="32"/>
        <source>Lock Screen</source>
        <translation>Læsa skjá</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="34"/>
        <source>Log Out</source>
        <translation>Skrá út</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="36"/>
        <source>Suspend</source>
        <translation>Setja í bið</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="38"/>
        <source>Reboot</source>
        <translation>Endurræsa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="40"/>
        <source>Shutdown</source>
        <translation>Slökkva</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="43"/>
        <location filename="../main.cpp" line="51"/>
        <source>Pop-up with exit options for MX Fluxbox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="44"/>
        <source>Display buttons in a vertical window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="45"/>
        <source>Display buttons in a horizontal window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="46"/>
        <source>Timeout duration in seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="47"/>
        <source>use -v, --vertical to display buttons vertically
use -h, --horizontal to display buttons horizontally.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Usage: exit-options [options]
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Options:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>  -h, --horizontal	 Option to display buttons horizontally</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>  -v, --vertical	 Option to display buttons vertically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="56"/>
        <source>  -t, --timeout &lt;sec&gt;	 Timeout duration in seconds
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>The display orientation option used will be remembered and used the next time you start the app</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>Alternativelly, set the option &apos;layout=horizontal&apos; or &apos;layout=vertical&apos; in ~/.config/MX-Linux/exit-options.conf</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="63"/>
        <source>To set the timeout in exit-options.conf use &apos;timeout=X&apos; where X is the timeout in seconds.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>You can define custom icons by adding IconName=/path/iconame.ext in the exit-options.conf file. The names of the icons that you remap: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Other options that can be set in the exit-options.conf file: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> exit-options_25.4.tar.xz: BUILD/translations/exit-options_is.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="is">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="26"/>
        <source>Restart Fluxbox</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="28"/>
        <source>Restart IceWM</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="30"/>
        <source>Restart JWM</source>
        <translation>Endurræsa JWM</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="38"/>
        <source>Lock Screen</source>
        <translation>Læsa skjá</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="36"/>
        <source>Log Out</source>
        <translation>Skrá út</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>Suspend</source>
        <translation>Setja í bið</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="40"/>
        <source>Reboot</source>
        <translation>Endurræsa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="42"/>
        <source>Shutdown</source>
        <translation>Slökkva</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="48"/>
        <location filename="../main.cpp" line="56"/>
        <source>Pop-up with exit options for MX Fluxbox</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>Display buttons in a vertical window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>Display buttons in a horizontal window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Timeout duration in seconds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>use -v, --vertical to display buttons vertically
use -h, --horizontal to display buttons horizontally.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>Usage: exit-options [options]
</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Options:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>  -h, --horizontal	 Option to display buttons horizontally</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>  -v, --vertical	 Option to display buttons vertically</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>  -t, --timeout &lt;sec&gt;	 Timeout duration in seconds
</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>The display orientation option used will be remembered and used the next time you start the app</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="64"/>
        <source>Alternativelly, set the option &apos;layout=horizontal&apos; or &apos;layout=vertical&apos; in ~/.config/MX-Linux/exit-options.conf</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>To set the timeout in exit-options.conf use &apos;timeout=X&apos; where X is the timeout in seconds.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="69"/>
        <source>You can also use &apos;timeout=off&apos; to turn the timeout off.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>You can define custom icons by adding IconName=/path/iconame.ext in the exit-options.conf file. The names of the icons that you remap: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>Other options that can be set in the exit-options.conf file: %1</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
